@@ -34,14 +34,13 @@
 #include <libspi/spi-private.h>
 #include "accessible.h"
 #include "application.h"
-
 #include <bonobo-activation/bonobo-activation-register.h>
 
 #undef SPI_BRIDGE_DEBUG
 
 #define DBG(a,b) if(_dbg>=(a))b
 
-static int _dbg = 0;
+int _dbg = 0;
 static CORBA_Environment ev;
 static Accessibility_Registry registry = CORBA_OBJECT_NIL;
 static Accessibility_DeviceEventController device_event_controller = CORBA_OBJECT_NIL;
@@ -160,6 +159,8 @@ atk_bridge_init (gint *argc, gchar **argv[])
       g_error ("Could not initialize Bonobo");
     }
 
+  /* Create the accessible application server object */
+  this_app = spi_application_new (atk_get_root ());
   /*
    * We only want to enable the bridge for top level
    * applications, we detect bonobo components by seeing
@@ -204,8 +205,8 @@ spi_atk_bridge_do_registration (void)
   bonobo_activate ();
 
   /* Create the accessible application server object */
-
-  this_app = spi_application_new (atk_get_root ());
+  if (this_app == NULL)
+    this_app = spi_application_new (atk_get_root ());
 
   DBG (1, g_message ("About to register application\n"));
 
@@ -464,7 +465,10 @@ gnome_accessibility_module_init (void)
 {
   atk_bridge_init (NULL, NULL);
 
-  g_print("Atk Accessibilty bridge initialized\n");
+  if (g_getenv ("AT_BRIDGE_SHUTDOWN"))
+    {
+	g_print("Atk Accessibility bridge initialized\n");
+    }
 }
 
 void
@@ -481,7 +485,10 @@ gnome_accessibility_module_shutdown (void)
   atk_bridge_initialized = FALSE;
   this_app = NULL;
 
-  g_print("Atk Accessibilty bridge shutdown\n");
+  if (g_getenv ("AT_BRIDGE_SHUTDOWN"))
+    {
+	g_print("Atk Accessibility bridge shutdown\n");
+    }
 
   listener_ids = NULL;
   atk_remove_focus_tracker (atk_bridge_focus_tracker_id);
@@ -773,7 +780,7 @@ spi_init_keystroke_from_atk_key_event (Accessibility_DeviceEvent  *keystroke,
   else
 #endif
   if (!event)
-    {
+    { /* this doesn't really need translating */
       g_print (_("WARNING: NULL key event reported."));
     }
   
@@ -830,7 +837,10 @@ spi_atk_bridge_key_listener (AtkKeyEventStruct *event, gpointer data)
   result = Accessibility_DeviceEventController_notifyListenersSync (
 	  spi_atk_bridget_get_dec (), &key_event, &ev);
 
-  CORBA_exception_free (&ev);
+  if (BONOBO_EX(&ev)) {
+      result = FALSE;
+      CORBA_exception_free (&ev);
+  }
 
   return result;
 }
@@ -1015,7 +1025,7 @@ spi_atk_tidy_windows (void)
         {
           spi_atk_emit_eventv (G_OBJECT (child), 0, 0, &any, "window:deactivate");
         }
-      g_free (stateset);
+      g_object_unref (stateset);
 
       spi_atk_emit_eventv (G_OBJECT (child), 0, 0, &any, "window:destroy");
       g_object_unref (child);
